@@ -312,7 +312,7 @@ class CmdChannel(COMMAND_DEFAULT_CLASS):
 
         """
         if not channel.access(self.caller, "send"):
-            caller.msg(f"You are not allowed to send messages to channel {channel}")
+            self.caller.msg(f"You are not allowed to send messages to channel {channel}")
             return
 
         # avoid unsafe tokens in message
@@ -489,9 +489,8 @@ class CmdChannel(COMMAND_DEFAULT_CLASS):
 
     def create_channel(self, name, description, typeclass=None, aliases=None):
         """
-        Create a new channel. Its name must not previously exist
-        (users can alias as needed). Will also connect to the
-        new channel.
+        Create a new channel. Its name must not previously exist (case agnostic)
+        (users can alias as needed). Will also connect to the new channel.
 
         Args:
             name (str): The new channel name/key.
@@ -880,7 +879,6 @@ class CmdChannel(COMMAND_DEFAULT_CLASS):
 
         if "create" in switches:
             # create a new channel
-
             if not self.access(caller, "manage"):
                 self.msg("You don't have access to use channel/create.")
                 return
@@ -937,7 +935,7 @@ class CmdChannel(COMMAND_DEFAULT_CLASS):
                 )
             elif len(found_channels) > 1:
                 errors.append(
-                    "Multiple possible channel matches/alias for '{channel_name}':\n"
+                    f"Multiple possible channel matches/alias for '{channel_name}':\n"
                     + ", ".join(chan.key for chan in found_channels)
                 )
             else:
@@ -1925,6 +1923,7 @@ class CmdDiscord2Chan(COMMAND_DEFAULT_CLASS):
         /delete  - alias to remove
         /guild   - toggle the Discord server tag on/off
         /channel - toggle the Evennia/Discord channel tags on/off
+        /start   - tell the bot to start, in case it lost its connection
 
     Example:
         discord2chan mydiscord = 555555555555555
@@ -1943,6 +1942,7 @@ class CmdDiscord2Chan(COMMAND_DEFAULT_CLASS):
         "guild",
         "list",
         "remove",
+        "start",
     )
     locks = "cmd:serversetting(DISCORD_ENABLED) and pperm(Developer)"
     help_category = "Comms"
@@ -1973,6 +1973,14 @@ class CmdDiscord2Chan(COMMAND_DEFAULT_CLASS):
                 f"WARNING: The Discord bot's typeclass is '{discord_bot.typeclass_path}'. This does not match {settings.DISCORD_BOT_CLASS} in settings!"
             )
 
+        if "start" in self.switches:
+            if discord_bot.sessions.all():
+                self.msg("The Discord bot is already running.")
+            else:
+                discord_bot.start()
+                self.msg("Starting the Discord bot session.")
+            return
+
         if "guild" in self.switches:
             discord_bot.db.tag_guild = not discord_bot.db.tag_guild
             self.msg(
