@@ -2,6 +2,8 @@
 Base typeclass for in-game Channels.
 
 """
+import re
+
 from django.contrib.contenttypes.models import ContentType
 from django.urls import reverse
 from django.utils.text import slugify
@@ -65,7 +67,7 @@ class DefaultChannel(ChannelDB, metaclass=TypeclassBase):
 
     # default nick-alias replacements (default using the 'channel' command)
     channel_msg_nick_pattern = r"{alias}\s*?|{alias}\s+?(?P<arg1>.+?)"
-    channel_msg_nick_replacement = "channel {channelname} = $1"
+    channel_msg_nick_replacement = "@channel {channelname} = $1"
 
     def at_first_save(self):
         """
@@ -98,6 +100,8 @@ class DefaultChannel(ChannelDB, metaclass=TypeclassBase):
                 self.attributes.add("desc", cdict["desc"])
             if cdict.get("tags"):
                 self.tags.batch_add(*cdict["tags"])
+            if cdict.get("attrs"):
+                self.attributes.batch_add(*cdict["attrs"])
 
     def basetype_setup(self):
         self.locks.add("send:all();listen:all();control:perm(Admin)")
@@ -475,7 +479,7 @@ class DefaultChannel(ChannelDB, metaclass=TypeclassBase):
 
         # the message-pattern allows us to type the channel on its own without
         # needing to use the `channel` command explicitly.
-        msg_nick_pattern = self.channel_msg_nick_pattern.format(alias=alias)
+        msg_nick_pattern = self.channel_msg_nick_pattern.format(alias=re.escape(alias))
         msg_nick_replacement = self.channel_msg_nick_replacement.format(channelname=chan_key)
         user.nicks.add(
             msg_nick_pattern,
